/****************************************************************************
 * apps/system/ntpc/ntpcstart_main.c
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <stdlib.h>
#include <stdio.h>

#include "netutils/ntpclient.h"

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * ntpcstart_main
 ****************************************************************************/

int main(int argc, FAR char *argv[])
{
  int pid;

  printf("Starting NTP client...\n");
  printf("Using NTP servers: %s\n", CONFIG_NETUTILS_NTPCLIENT_SERVER);

  pid = ntpc_start();
  if (pid < 0)
    {
      fprintf(stderr, "ERROR: ntpc_start() failed\n");
      return EXIT_FAILURE;
    }

  printf("NTP client started successfully (task ID: %d)\n", pid);
  printf("NTP client is now running in the background\n");

  return EXIT_SUCCESS;
}
